Crate toml_spanner

Crate toml_spanner 

toml-spanner

This create is fork of toml-span adding more support for the toml 1.1.0 spec, along the way,

Differences from toml

First off I just want to be up front and clear about the differences/limitations of this crate versus toml

  1. No serde support for deserialization, there is a serde feature, but that only enables serialization of the Value and Spanned types.
  2. No toml serialization. This crate is only intended to be a span preserving deserializer, there is no intention to provide serialization to toml, especially the advanced format preserving kind provided by toml-edit.
  3. No datetime deserialization. It would be trivial to add support for this (behind an optional feature), I just have no use for it at the moment. PRs welcome.

License

This contribution is dual licensed under EITHER OF

at your option.

Re-exports

pub use de::parse;
pub use span::Span;
pub use span::Spanned;
pub use value::Value;

Modules

de
Core deserialization logic that deserializes toml content to Value
de_helpers
Provides helpers for deserializing Value/ValueInner into Rust types
impl_serdeserde
Provides serde::Serialize support for Value and Spanned
span
Provides span helpers
tokens
The tokenizer is publicly exposed if you wish to use it instead
value
Contains the Value and ValueInner containers into which all toml contents can be deserialized into and either used directly or fed into crate::Deserialize or your own constructs to deserialize into your own types

Structs

DeserError
When deserializing, it’s possible to collect multiple errors instead of earlying out at the first error
Error
Error that can occur when deserializing TOML.

Enums

ErrorKind
Errors that can occur when deserializing a type.

Traits

Deserialize
This crate’s equivalent to serde::Deserialize
DeserializeOwned
This crate’s equivalent to serde::DeserializeOwned